@@ -1,11 +1,11 @@
-## ----libraries, message=FALSE--------------------------------------------
+## ----libraries, message=FALSE-------------------------------------------------
 library(fingertipsR)
 library(ggplot2)
 
-## ----select indicators, eval=FALSE---------------------------------------
+## ----select indicators, eval=FALSE--------------------------------------------
 #  inds <- select_indicators()
 
-## ----inds, echo=FALSE----------------------------------------------------
+## ----inds, echo=FALSE---------------------------------------------------------
 inds <- c(90630, 10101, 10301, 
           92313, 10401, 11401, 
           10501, 92314, 11502, 
@@ -15,10 +15,10 @@ inds <- c(90630, 10101, 10301,
           22001, 22002, 90244)
 inds
 
-## ----fingertips redred---------------------------------------------------
-df <- fingertips_redred(inds, Comparator = "England")
+## ----fingertips redred--------------------------------------------------------
+df <- fingertips_redred(inds, AreaTypeID = 102, Comparator = "England")
 
-## ----ggplot, fig.height=16, fig.width=8----------------------------------
+## ----ggplot, fig.height=16, fig.width=8---------------------------------------
 df$IndicatorName <- sapply(strwrap(df$IndicatorName, 60, 
                                    simplify = FALSE), 
                            paste, collapse= "\n")
